@@ -6,12 +6,13 @@ set -e
 set -x
 
 # Build inplace so that nosetests can be run inside source directory
-python setup.py install build_ext --inplace --symengine-dir=$our_install_dir
+python3 setup.py install build_ext --inplace --symengine-dir=$our_install_dir
 
 # Test python wrappers
-py.test -s -v $PYTHON_SOURCE_DIR/symengine/tests/test_*.py
+python3 -m pip install pytest
+python3 -m pytest -s -v $PYTHON_SOURCE_DIR/symengine/tests/test_*.py
 mkdir -p empty && cd empty
-python $PYTHON_SOURCE_DIR/bin/test_python.py
+python3 $PYTHON_SOURCE_DIR/bin/test_python.py
 cd ..
 
 if [[ "${TRIGGER_FEEDSTOCK}" == "yes" ]]; then
